==> php-league-csv_9.9.0.orig.tar.xz: php-league-csv-9.9.0/src/Info.php <==
<?php

/**
 * League.Csv (https://csv.thephpleague.com)
 *
 * (c) Ignace Nyamagana Butera <nyamsprod@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace League\Csv;

use function array_fill_keys;
use function array_filter;
use function array_reduce;
use function array_unique;
use function count;
use function strlen;
use const COUNT_RECURSIVE;

final class Info implements ByteSequence
{
    private const BOM_SEQUENCE_LIST = [
        ByteSequence::BOM_UTF32_BE,
        ByteSequence::BOM_UTF32_LE,
        ByteSequence::BOM_UTF16_BE,
        ByteSequence::BOM_UTF16_LE,
        ByteSequence::BOM_UTF8,
    ];

    /**
     * Returns the BOM sequence found at the start of the string.
     *
     * If no valid BOM sequence is found an empty string is returned
     */
    public static function fetchBOMSequence(string $str): ?string
    {
        foreach (self::BOM_SEQUENCE_LIST as $sequence) {
            if (str_starts_with($str, $sequence)) {
                return $sequence;
            }
        }

        return null;
    }

    /**
     * Detect Delimiters usage in a {@link Reader} object.
     *
     * Returns a associative array where each key represents
     * a submitted delimiter and each value the number CSV fields found
     * when processing at most $limit CSV records with the given delimiter
     *
     * @param array<string> $delimiters
     *
     * @return array<string, int>
     */
    public static function getDelimiterStats(Reader $csv, array $delimiters, int $limit = 1): array
    {
        $stmt = Statement::create()->offset(0)->limit($limit);

        $delimiterStats = function (array $stats, string $delimiter) use ($csv, $stmt): array {
            $csv->setDelimiter($delimiter);
            $foundRecords = [];
            foreach ($stmt->process($csv)->getRecords() as $record) {
                if (1 < count($record)) {
                    $foundRecords[] = $record;
                }
            }

            $stats[$delimiter] = count($foundRecords, COUNT_RECURSIVE);

            return $stats;
        };

        $currentDelimiter = $csv->getDelimiter();
        $currentHeaderOffset = $csv->getHeaderOffset();

        $csv->setHeaderOffset(null);

        $stats = array_reduce(
            array_unique(array_filter($delimiters, fn (string $value): bool => 1 === strlen($value))),
            $delimiterStats,
            array_fill_keys($delimiters, 0)
        );

        $csv->setHeaderOffset($currentHeaderOffset);
        $csv->setDelimiter($currentDelimiter);

        return $stats;
    }
}

==> php-league-csv_9.23.0+dfsg.orig.tar.xz: php-league-csv-9.23.0/src/Info.php <==
<?php

/**
 * League.Csv (https://csv.thephpleague.com)
 *
 * (c) Ignace Nyamagana Butera <nyamsprod@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

declare(strict_types=1);

namespace League\Csv;

use Deprecated;

use function array_fill_keys;
use function array_filter;
use function array_reduce;
use function array_unique;
use function count;
use function strlen;

use const COUNT_RECURSIVE;

final class Info implements ByteSequence
{
    /**
     * Returns the BOM sequence found at the start of the string.
     *
     * If no valid BOM sequence is found an empty string is returned
     *
     * @deprecated since version 9.16.0
     * @see Bom::tryFromSequence()
     * @codeCoverageIgnore
     */
    #[Deprecated(message:'use League\Csv\Bom::tryFromSequence() instead', since:'league/csv:9.16.0')]
    public static function fetchBOMSequence(string $str): ?string
    {
        return Bom::tryFromSequence($str)?->value;
    }

    /**
     * Detect Delimiters usage in a {@link Reader} object.
     *
     * Returns a associative array where each key represents
     * a submitted delimiter and each value the number CSV fields found
     * when processing at most $limit CSV records with the given delimiter
     *
     * @param array<string> $delimiters
     * @param int<-1, max> $limit
     *
     * @return array<string, int>
     */
    public static function getDelimiterStats(Reader $csv, array $delimiters, int $limit = 1): array
    {
        $currentHeaderOffset = $csv->getHeaderOffset();
        $currentDelimiter = $csv->getDelimiter();

        $stats = array_reduce(
            array_unique(array_filter($delimiters, fn (string $value): bool => 1 === strlen($value))),
            fn (array $stats, string $delimiter): array => [
                ...$stats,
                ...[$delimiter => count([
                    ...$csv
                        ->setHeaderOffset(null)
                        ->setDelimiter($delimiter)
                        ->slice(0, $limit)
                        ->filter(fn (array $record, int|string $key): bool => 1 < count($record)),
                ], COUNT_RECURSIVE)],
            ],
            array_fill_keys($delimiters, 0)
        );

        $csv->setHeaderOffset($currentHeaderOffset);
        $csv->setDelimiter($currentDelimiter);

        return $stats;
    }
}
